pybofh documentation
====================

*pybofh*, short for *brukerorganisering for hvermannsen*, is a `Cerebrum`_
administration tool.

It is an interactive XML/RPC CLI client for a ``Cerebrum.modules.bofhd``
server.  It is unlikely you want to use this software unless you know
what Cerebrum is.

.. toctree::
   :titlesonly:
   :maxdepth: 2

   Introduction <intro>
   install
   develop


.. toctree::
   :caption: Scripts
   :maxdepth: 1
   :glob:

   man/*


.. toctree::
   :caption: Modules
   :maxdepth: 1
   :glob:

   modules/index
   modules/*


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _Cerebrum: https://www.usit.uio.no/om/tjenestegrupper/cerebrum/
